@@ -4,8 +4,8 @@
 #' @description Given a (response) pattern frequencies table this function returns a dataset representation of it.
 #' @details No details
 #' 
-#' @param x an object of class "matrix" which is a (response) pattern frequencies table. It is assumed, that the last column of the object \code{x} represents the frequencies of the (respose) patern represented by the other columns in \code{x}.
-#' @param fact logical, default is \code{(fact=FALSE)}. If this argument is set to \code{(fact=TRUE)} the result is coerced to a data.frame with factor variables.
+#' @param x typically an object of class "matrix" which is a (response) pattern frequencies table. \code{data.frames} are converted into a matrix with \code{\link{data.matrix}}. It is assumed, that the last column of the object \code{x} represents the frequencies of the (respose) patern represented by the other columns in \code{x}.
+#' @param fact logical, default is \code{(fact=TRUE)} and the result is coerced to a data.frame with factor variables. If this argument is set to \code{(fact=FALSE)} a matrix object with numerical values is returned.
 #' @param ... additional parameters passed trough. This is an option to assign factor labels to the resulting \code{data.frame} (when setting argument \code{fact=TRUE}) --> see \code{factor} in the \code{base} package and examples.
 #' 
 #' WARNING using this option will only work correct when all 'pattern' columns (variables) in the frequencies table share the same number of categories    
@@ -23,7 +23,7 @@
 ############### start of function definition ##################
 ########### pattern frequency to data conversion ##############
 ################ jhheine at googlemail.com ####################
-fre2dat <- function(x,fact=FALSE,...) {
+fre2dat <- function(x,fact=TRUE,...) {
 	x <- data.matrix(x)
 	lp <- dim(x)[2]
 	pp <- dim(x)[1] # könnte zu kurz sein! je nach x
